searchData={"items":[{"type":"module","title":"CurlReq","doc":"Req is awesome, but the world speaks curl.\n\nNext time you're debugging a 3rd party API and need to ask for support, you can just toss in this line:\n\n```elixir\n|> CurlReq.inspect()\n```\n\nAnd you'll have the full curl command.\n\n```elixir\n# Turn a Req request into a `curl` command.\n\niex> Req.new(url: \"/fact\", base_url: \"https://catfact.ninja/\")\n...> |> CurlReq.to_curl()\n\"curl -H \\\"accept-encoding: gzip\\\" -H \\\"user-agent: req/0.4.14\\\" -X GET https://catfact.ninja/fact\" \n\n# Or use `CurlReq.inspect/2` to inspect inline.\n\niex> Req.new(url: \"/fact\", base_url: \"https://catfact.nijna/\")\n...> |> CurlReq.inspect(label: \"MY REQ\")\n...> # |> Req.request!()\n\n```\n\n`CurlReq` also implements the `~CURL` sigil, which converts a curl command to its corresponding Req request.\n\n```elixir\niex> import CurlReq\n...> ~CURL(curl https://www.google.com)\n...> # |> Req.request!()\n\n```","ref":"CurlReq.html"},{"type":"module","title":"Installation - CurlReq","doc":"The package can be installed\nby adding `curl_req` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:curl_req, \"~> 0.98.0\"}\n  ]\nend\n```\n\nThe docs can be found at  .","ref":"CurlReq.html#module-installation"},{"type":"module","title":"Contributions - CurlReq","doc":"Contributions are welcome! There are gaps in the library, and this is open source, so let's work together to fill them!\n\n- [ ] ~CURL sigil handles newlines\n- [x] curl [url]\n- [x] curl -H\n- [x] curl -X\n- [x] curl -d\n- [ ] curl -b\n- [ ] curl long form options (--header, --body, etc)\n- [ ] Req Plugin to log curl command (like `TeslaCurl`)","ref":"CurlReq.html#module-contributions"},{"type":"module","title":"How to contribute - CurlReq","doc":"- Clone the repository to your computer.\n- Add to your mix.exs file in your project: `{:curl_req, path: \"~/path/to/curl_req\"}`.\n- Tinker until it does what you want.\n- Add a test covering your case.\n- Submit a PR!","ref":"CurlReq.html#module-how-to-contribute"},{"type":"function","title":"CurlReq.inspect/2","doc":"Inspect a Req struct in curl syntax.\n\nReturns the unchanged `req`, just like `IO.inspect/2`.","ref":"CurlReq.html#inspect/2"},{"type":"function","title":"Examples - CurlReq.inspect/2","doc":"iex> Req.new(url: URI.parse(\"https://www.google.com\"))\n    ...> |> CurlReq.inspect()\n    ...> # |> Req.request!()","ref":"CurlReq.html#inspect/2-examples"},{"type":"macro","title":"CurlReq.sigil_CURL/2","doc":"Transforms a curl command into a Req request.","ref":"CurlReq.html#sigil_CURL/2"},{"type":"macro","title":"Examples - CurlReq.sigil_CURL/2","doc":"iex> import CurlReq\n    ...> ~CURL(curl \"https://www.google.com\")\n    %Req.Request{method: :get, url: URI.parse(\"https://www.google.com\")}","ref":"CurlReq.html#sigil_CURL/2-examples"},{"type":"function","title":"CurlReq.to_curl/1","doc":"Transforms a Req request into a curl command.","ref":"CurlReq.html#to_curl/1"},{"type":"function","title":"Examples - CurlReq.to_curl/1","doc":"iex> Req.new(url: URI.parse(\"https://www.google.com\"))\n    ...> |> CurlReq.to_curl()\n    ~S(curl -H \"accept-encoding: gzip\" -H \"user-agent: req/0.4.14\" -X GET https://www.google.com)","ref":"CurlReq.html#to_curl/1-examples"},{"type":"type","title":"CurlReq.inspect_opt/0","doc":"","ref":"CurlReq.html#t:inspect_opt/0"},{"type":"type","title":"CurlReq.req_request/0","doc":"","ref":"CurlReq.html#t:req_request/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}